function [timeOUT,pOUT,dddpOUT,dtdhOUT] = get_tt_other(phases,EQdepth, delta)
%   get_tt_other  find travel time and ray parameter at many offests
% Usage   [time,p,dddp,dtdh] = get_tt_other(phase,EQdepth, delta);
% This program interpolates and matches ray parameters to find the travel 
% time and ray parameter, using the IASPI91 model, for an earthquake at
% a given depth and a discontinuity
%         Example  [time,p,dddp,dtdh] = get_tt_other('S683P ',438,73);


Exotic = real(phases) >47 & real(phases) < 58;
DoExotic = max(Exotic')';
NumPhases = size(phases,1);

for i=1:NumPhases;
  if DoExotic(i) ==1
    phase = phases(i,:);
    SizeName = size(phase,2);
    realName = real(phase);
    Number = realName > 47 & realName < 58;
    dpt = str2num(setstr(realName(Number)));
    
    phase1 = 'S     ';
    if realName(1) == 112 | realName(1) ==80
      phase1 = 'P     ';
    end
    phase2 = 'S     ';
    if realName(2+size(num2str(dpt),2)) == 112 | realName(2+size(num2str(dpt),2)) == 80
      phase2 = 'P     ';
    end
    range = 0:2.5:95;
    
    Dis2 = 30;
    if dpt<=800 [t,p] = get_ttt(phase2,dpt,range); 
      [Max2,b] = max(p); [Dis2] = range(b);
    end
    
    % table one - P wave from discont.
    delt1 = [max(min(delta),Dis2*2)*.9: .5 : max(delta)+.5]; 
    close = [ 0 : 0.05 :3];			
    close3 = [ 0 : 0.05 : 3];			
    
    if dpt <= 800
      [t1, p1, dddp660] = get_ttt(phase2,dpt, delt1);% original time and ray parm.
      [t2, p2, dddp2] = get_ttt (phase1, dpt, close); % table 2- s wave 660 up
      [t3, p3, dddp3, dtdh3] = get_ttt (phase1, EQdepth, close);% S from event up
      
      % esp. for shallow earthquakes, the range of ray param. is too high --
      % a ray traveling straight sideways can only go so far
      % therefore, elimate higher distances
      x = diff(p3)>0;
      if min(x)==0
		x = [x;0];
		x =logical(x);
		t3=t3(x);p3=p3(x);dddp3=dddp3(x);
		dtdh3=dtdh3(x);close3=close(x);
	  end
	  
	  %  If the event is above discont, flip some signs
	  if EQdepth > dpt
		close = close * (-1); 
		close3 = close3 * (-1); 
		t2 = t2 * (-1); 
		t3 = t3 * (-1);
		%	p2 = p2 * (-1);
		%	p3 = p3 * (-1);
		dddp2 = dddp2 * (-1);
		dddp3 = dddp3 * (-1);
	  end
	  
	  % These evaluate the S waves at the P ray parms.
	  tS660up = interpol(p2,t2,p1); dS660up = interpol(p2,close',p1);
      dddpS2 = interpol(p2,dddp2,p1); 
      tSeventup = interpol(p3,t3,p1); dSeventup = interpol(p3,close3',p1);
      dddpS3 = interpol(p3,dddp3,p1); dtdhS3 = interpol(p3,dtdh3,p1);
      
	  time1 = t1 + tS660up - tSeventup;
	  dist1 = delt1' + dS660up - dSeventup;
      dddp1 = dddp660 + dddpS2 - dddpS3;
	  
	  % interpolate tables to get values at desired distances
      p=interpol(dist1,p1,delta');
	  time=interpol(dist1,time1,delta');
	  dddp=interpol(dist1,dddp1,delta');
	  dtdh=-1*interpol(dist1,dtdhS3,delta');
	end
	
	if dpt>800
      dpt2=790; 
      dpt1=800;
      [t1, p1, dddp660] = get_ttt(phase2,dpt1, delt1);% original time and ray parm.
      [t2, p2, dddp2] = get_ttt (phase1, dpt1, close); % table 2- s wave 660 up
      [t3, p3, dddp3, dtdh3] = get_ttt (phase1, EQdepth, close);% S from event up
      
      % esp. for shallow earthquakes, the range of ray param. is too high --
      % a ray traveling straight sideways can only go so far
      % therefore, elimate higher distances
      gradp3 = gradient(p3); % matlab ver. 5 change
      if min(gradp3)<0
		for i=length(gradp3):-1:1
		  if gradp3(i) < 0;  
			x=i;
		  end
		end
		t3=t3(1:x);p3=p3(1:x);dddp3=dddp3(1:x);
		dtdh3=dtdh3(1:x);close3=close(1:x);
	  end
      
      % These evaluate the S waves at the P ray parms.
      tS660up = interpol(p2,t2,p1); dS660up = interpol(p2,close',p1);
      dddpS2 = interpol(p2,dddp2,p1); 
      tSeventup = interpol(p3,t3,p1); dSeventup = interpol(p3,close3',p1);
      dddpS3 = interpol(p3,dddp3,p1); dtdhS3 = interpol(p3,dtdh3,p1);
      
      time1 = t1 + tS660up - tSeventup;
      dist1 = delt1' + dS660up - dSeventup;
      dddp1 = dddp660 + dddpS2 - dddpS3;
      
      % interpolate tables to get values at desired distances
      p800=interpol(dist1,p1,delta');
      time800=interpol(dist1,time1,delta');
      dddp800=interpol(dist1,dddp1,delta');
      dtdh800=-1*interpol(dist1,dtdhS3,delta');
      
      % evaluate at 790km
      [t1, p1, dddp660] = get_ttt(phase2,dpt2, delt1);% original time and ray parm.
      [t2, p2, dddp2] = get_ttt (phase1, dpt2, close); % table 2- s wave 660 up
      
      % esp. for shallow earthquakes, the range of ray param. is too high --
      % a ray traveling straight sideways can only go so far
      % therefore, elimate higher distances
      gradp3 = gradient(p3); % matlab ver. 5 change
      if min(gradp3)<0
		for i=length(gradp3):-1:1
		  if gradp3(i) < 0;  
			x=i;
		  end
		end
		t3=t3(1:x);p3=p3(1:x);
		dddp3=dddp3(1:x);
		dtdh3=dtdh3(1:x);
		close3=close(1:x);
	  end
	  
	  % These evaluate the S waves at the P ray parms.
      tS660up = interpol(p2,t2,p1); 
      dS660up = interpol(p2,close',p1);
      dddpS2 = interpol(p2,dddp2,p1); 
      tSeventup = interpol(p3,t3,p1); dSeventup = interpol(p3,close3',p1);
      dddpS3 = interpol(p3,dddp3,p1); dtdhS3 = interpol(p3,dtdh3,p1);
      
      time1 = t1 + tS660up - tSeventup;
      dist1 = delt1' + dS660up - dSeventup;
      dddp1 = dddp660 + dddpS2 - dddpS3;
      
      % interpolate tables to get values at desired distances
      p790=interpol(dist1,p1,delta');
      time790=interpol(dist1,time1,delta');
      dddp790=interpol(dist1,dddp1,delta');
      dtdh790=-1*interpol(dist1,dtdhS3,delta');
      
      diffdpt = dpt - 800; diffdpts = dpt1-dpt2;
      p = p800 +  (p800 - p790) * diffdpt/diffdpts;
      time = time800 + (time800 - time790) * diffdpt/diffdpts;
      dddp = dddp800 +  (dddp800 - dddp790) * diffdpt/diffdpts;
      dtdh = dtdh800 +  (dtdh800 - dtdh790) * diffdpt/diffdpts;
    end
    
    % set interpolate = 1 for interpolation, 0 for extrapolation, then divide to
    % give values of inf for extrapolation
    interpolate=(delta'>=min(dist1)) & (delta'<=max(dist1));    
    pOUT(:,i)=p./interpolate;
    dddpOUT(:,i)=dddp./interpolate;
    dtdhOUT(:,i)=dtdh./interpolate;
    timeOUT(:,i)=time./interpolate;
    
  elseif phases(i,1:3) == 'SSS';
    phase1 = 'S     ';
    r = 6371-EQdepth;
    [Vp,Vs] = iasp91(r);
    RayParm = (r)/Vs*pi/180;
    % S from EQ
    delt1 = min(delta)/4:.5:max(delta)/3;
    [t1, p1, dddp1, dtdh1] = get_ttt(phase1,EQdepth, delt1);
    % S bounces
    delt2 = min(delta)/4:.5:max(delta)/2;
    [t2, p2, dddp2, dtdh2] = get_ttt(phase1,0, delt2);
    % Check to make sure this is downgoing SSS
    Check = (p2 < RayParm); [a,b] = max(Check');
    dddp2 = dddp2(Check); dtdh2 = dtdh2(Check);
    p2 = p2(Check); t2 = t2(Check); delt2 = delt2(Check);
    Check = (p1 < RayParm); [c,d] = max(Check');
    if b > 1 Check(d:d+1) = [0 0]; end
    dddp1 = dddp1(Check); dtdh1 = dtdh1(Check);
    p1 = p1(Check); t1 = t1(Check); delt1 = delt1(Check);
    
    % Evaluate everything at the same ray parms.
    tS2 = interpol (p2,t2,p1); dS2 = interpol (p2,delt2',p1);
    dddpS2 = interpol (p2,dddp2,p1);
    dist1 = dS2  * 2+ delt1';
    time1 = tS2  * 2+ t1;
    dddpS = dddpS2 * 2 + dddp1;
    
    % interpolate tables to get values at desired distances
    p=interpol(dist1,p1,delta');
    time=interpol(dist1,time1,delta');
    dddp=interpol(dist1,dddpS,delta');
    dtdh=interpol(dist1,dtdh1,delta');
    % set interpolate = 1 for interpolation, 0 for extrapolation, then divide to
    % give values of inf for extrapolation
    interpolate=(delta'>=min(dist1)) & (delta'<=max(dist1));    
    pOUT(:,i)=p./interpolate;
    dddpOUT(:,i)=dddp./interpolate;
    dtdhOUT(:,i)=dtdh./interpolate;
    timeOUT(:,i)=time./interpolate;

  else
    [timeOUT(:,i), pOUT(:,i), dddpOUT(:,i), dtdhOUT(:,i)] = ...
      get_ttt (phases(i,:), EQdepth, delta);
  end
end

