function [time,p,dddp,dtdh]=get_tt_sscs(depth,delta);
%   get_tt_sscs   find travel time and ray parameter for sScS
% USAGE: [time,p,dddp,dtdh]=get_tt_sscs(depth,delta);
%
%  get travel time, ray parameter and d(p)/d(delta) for the phase sScS
%
% depth = scalar depth (km)
% delta = row vector of epicentral distances
%
% time = column vector of travel times (s)
% p    = column vector of ray parameters (s/deg)
% dddp = column vector of d(delta)/d(ray parameter) (rad^2/s)
% dtdh = column vector of d(time)/d(depth) (km/s)
%
% time, ray parameter, dddp, and dtdh are given in the arrays for each 
% phase and delta.  if ray cannot be interpolated from tables 
% constructed here it is given a value of Inf

phase='ScS   '; depth_phase='S     ';

dScS=[1:95]';                                 % set distance range for tables
[tScS,pScS,dddpScS,dtdhScS]=get_ttt(phase,0,dScS');  % interpolate to get t, p, and dddp 
% plot(dScS,pScS,'-',dScS,pScS,'o'),title(phase),pause

%  get dS1, tS1, pS1 (distance, time, ray parameter for upgoing branch of S only)

[dS1,tS1,pS1,dddpS1,dtdhS1,ph] = get_tt_up(depth_phase,depth);
% plot(dS1,pS1,'-',dS1,pS1,'o'),title('S or P up'),pause

% interpolate to get d of upgoing S at the ray parameters corresponding to ScS table
% then evaluate  t, p, and dddp for upgoing S at these same distances

dS=interpol(pS1,dS1,pScS);
[tS,pS,dddpS,dtdhS]=get_ttt(depth_phase,depth,dS');  %interpolate to get t, p, and dddp
% plot(dS,pS,'-',dS,pS,'o'),title('S or P up again'),pause

disp(['max ray parameter error is ' num2str(max(abs(pS-pScS))) ]);

% we now have tables of ScS and upgoing S at the same set of ray parameters
% so t, p, dddp, dtdh of sScS are simply the sums of their values at fixed ray parameter 

dsScS=dS+dScS;
tsScS=tS+tScS;                
psScS=pScS;
dddpsScS=dddpS+dddpScS;
dtdhsScS=dtdhS;

% interpolate tables to get values at desired distances

p=interpol(dsScS,psScS,delta');
time=interpol(dsScS,tsScS,delta');
dddp=interpol(dsScS,dddpScS,delta');
dtdh=interpol(dsScS,dtdhScS,delta');

% set interpolate = 1 for interpolation, 0 for extrapolation, then divide to
% give values of inf for extrapolation
interpolate=(delta'>=min(dsScS)) & (delta'<=max(dsScS));    
p=p./interpolate;
dddp=dddp./interpolate;
dtdh=dtdh./interpolate;
time=time./interpolate;
