function prsTraceSubset
global Seis
global PlotState
global StaLat
global StaLon
global EvLat
global EvLon
global StaComp
global MinLatLonX
global MaxLatLonX
global MinLatLonY
global MaxLatLonY
global EvStaMapPatchList
global NumEvStaMapZooms
global XstackEvStaMap
global YstackEvStaMap

StaLat = [];
StaLon = [];
StaComp = [];
EvLat = [];
EvLon = [];
EvStaMapPatchList = [];
NumEvStaMapZooms = 0;
XstackEvStaMap = [];
YstackEvStaMap = [];

MinLatLonX = 100000;
MinLatLonY = MinLatLonX;
MaxLatLonX = - MinLatLonX;
MaxLatLonY = MaxLatLonX;

a = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
        'WindowButtonDownFcn','prsEvStaMapCallBacks(''btnDown'')',... 
	'Position',[0.2587    0.0789    0.4861    0.4667], ...
	'NumberTitle','off',...
	'Name','Event - Station Map',...
	'Menubar','none',...
	'Tag','EventStationMap');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.0    0.88    1.0    0.12], ...
	'Style','frame', ...
	'Tag','EvStaMapFrame');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.02 .94 .15 .05], ...
	'Style','radiobutton', ...
	'string','Exclude V',...
	'Callback','prsEvStaMapCallBacks(''ExcludeV'')',...
	'Tag','EvStaMapExcludeV');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.02 .89 .15 .05], ...
	'Style','radiobutton', ...
	'string','Exclude H2',...
	'Callback','prsEvStaMapCallBacks(''ExcludeH2'')',...
	'Tag','EvStaMapExcludeH2');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.17 .94 .15 .05], ...
	'Style','radiobutton', ...
	'string','Exclude H1',...
	'Callback','prsEvStaMapCallBacks(''ExcludeH1'')',...
	'Tag','EvStaMapExcludeH1');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.17 .89 .15 .05], ...
	'Style','radiobutton', ...
	'string','Exclude H',...
	'Callback','prsEvStaMapCallBacks(''ExcludeH'')',...
	'Tag','EvStaMapExcludeH');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.47 .94 .13 .05], ...
	'Style','pushbutton', ...
	'string','Select All',...
	'Callback','prsEvStaMapCallBacks(''SelectAll'')',...
	'Tag','EvStaMapSelectAll');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.47 .89 .13 .05], ...
	'Style','pushbutton', ...
	'string','Select None',...
	'Callback','prsEvStaMapCallBacks(''SelectNone'')',...
	'Tag','EvStaMapSelectNone');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.61 .94 .15 .05], ...
	'Style','pushbutton', ...
	'string','Select Region',...
	'Callback','prsEvStaMapCallBacks(''SelectRegion'')',...
	'Tag','EvStaMapSelectRegion');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[.61 .89 .15 .05], ...
	'Style','pushbutton', ...
	'string','Clear Region',...
	'Callback','prsEvStaMapCallBacks(''ClearRegion'')',...
	'Tag','EvStaMapClearRegion');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[0.86    0.94    0.12    0.05], ...
	'String','Close', ...
	'Callback','close(gcf)');


meanLat = 0;
meanLon = 0;
for j=1:length(Seis)
   meanLat = meanLat + Seis(j).Stla;
   meanLat = meanLat + Seis(j).Evla;
end
for j=1:length(Seis)
   meanLon = meanLon + Seis(j).Stlo;
   meanLon = meanLon + Seis(j).Evlo;
end
meanLat = meanLat /(2*length(Seis) );
meanLon = meanLon /(2*length(Seis) );

for j=1:length(Seis)
   Seis(j).MapSta = PlotUniqueStation(Seis(j),meanLat, meanLon);
   Seis(j).MapEvent = PlotUniqueEvent(Seis(j),meanLat, meanLon);
end 
set(gca,'position',[0.1300    0.05    0.7750    0.80])
set(gca,'box','on')
set(gca,'XTickLabel',[])
set(gca,'YTickLabel',[])
Xrange =  MaxLatLonX - MinLatLonX;
Yrange =  MaxLatLonY - MinLatLonY; 
xmin = MinLatLonX - .1 * Xrange;
xmax = MaxLatLonX + .1 * Xrange;
ymin = MinLatLonY - .1 * Yrange;
ymax = MaxLatLonY + .1 * Yrange;

set(gca,'xlim',[xmin,xmax],'ylim',[ymin,ymax])  

% ------------------------------------------------------------------







function hSta = PlotUniqueStation(Seis,meanLat, meanLon)
global StaLat
global StaLon
global StaComp

hSta = [];
if isempty(StaLat)
   StaLat(1) = Seis.Stla;
   StaLon(1) = Seis.Stlo;
   StaComp   = Seis.Component;
   hSta = DrawStation(Seis,meanLat, meanLon);
   return
else
   for j=1:length(StaLat)
      if StaLat(j) == Seis.Stla & StaLon(j) == Seis.Stlo
         if strcmp(StaComp(j,:), Seis.Component)
            return
         end
      end
   end
   M = length(StaLat);
   StaLat(M+1) = Seis.Stla;
   StaLon(M+1) = Seis.Stlo;
   StaComp = str2mat(StaComp,Seis.Component);
   hSta = DrawStation(Seis,meanLat, meanLon);
   return
end
% ------------------------------------------------------------------







function hEvent = PlotUniqueEvent(Seis,meanLat, meanLon)
global EvLat
global EvLon


hEvent = [];
if isempty(EvLat)
   EvLat(1) = Seis.Evla;
   EvLon(1) = Seis.Evlo;
   hEvent = DrawEvent(Seis,meanLat, meanLon);
   return
else
   for j=1:length(EvLat)
      if EvLat(j) == Seis.Evla & EvLon(j) == Seis.Evlo
         return
      end
   end
   M = length(EvLat);
   EvLat(M+1) = Seis.Evla;
   EvLon(M+1) = Seis.Evlo;
   hEvent = DrawEvent(Seis,meanLat, meanLon);
   return
end
% ------------------------------------------------------------------




function handle = DrawStation(Seis,meanLat, meanLon) 

[xsta, ysta] = LatLon2XY(Seis.Stla, Seis.Stlo, meanLat, meanLon);
handle = text(xsta, ysta, [Seis.Name ' (' GetComp(Seis) ')'],'color','b');
set(handle,'fontsize',8,'clipping','on');
if Seis.Hidden
   set(handle,'color',[.7 .7 .7],'fontsize',6)
end
% ------------------------------------------------------------------



function handle = DrawEvent(Seis,meanLat, meanLon) 

[xsta, ysta] = LatLon2XY(Seis.Evla, Seis.Evlo, meanLat, meanLon);
handle = text(xsta, ysta, GetEvent(Seis),'clipping','on');
if Seis.Hidden
   set(handle,'color',[.7 .7 .7],'fontsize',6)
end

% ------------------------------------------------------------------



function [xsta, ysta] = LatLon2XY(lat, lon, LatCenter, LonCenter)
global MinLatLonX
global MaxLatLonX
global MinLatLonY
global MaxLatLonY

xsta = lon - LonCenter;
ysta = lat - LatCenter;
if xsta < MinLatLonX
   MinLatLonX = xsta;
end
if xsta > MaxLatLonX
   MaxLatLonX = xsta;
end
if ysta < MinLatLonY
   MinLatLonY = ysta;
end
if ysta > MaxLatLonY
   MaxLatLonY = ysta;
end

% ------------------------------------------------------------------





function Comp = GetComp(Seis)

if ~strcmp(Seis.Component, '-12345')
   Comp = Seis.Component;
   return
end
if Seis.Cmpinc == 0
   Comp = 'V';
   return
end
sinmax = sin(pi/4);
if abs( sin(Seis.Cmpaz * pi / 180) ) < sinmax
   Comp = 'H1';
   return
end

Comp = 'H2';
return      
% ------------------------------------------------------------------






function EV = GetEvent( Seis )

if ~strcmp(Seis.Event,'-12345')
   EV = Seis.Event;
   return
end

EV = 'Epicenter';
return   