function prsUpdateSingleTraceWindow(mode)
global Seis
global PickWin 
global PlotState
global PhaseList

oldAxis = findobj('Tag' ,'RecSecAxis');
axes(PickWin.AxisHandle)

index = PickWin.IndexArray(PickWin.Current);
CurrentDist = Seis(index).Dist;
if PickWin.Current ~= PickWin.NewIndex
   for j=1:PickWin.Npicks
      delete(PickWin.Pick(j).LineHandle)
      delete(PickWin.Pick(j).Text1)
      delete(PickWin.Pick(j).Text2)
   end
   PickWin.Current = PickWin.NewIndex;
   index = PickWin.IndexArray(PickWin.Current);
   Xdata = get(Seis(index).TraceHandle,'Xdata');
   Ydata = get(Seis(index).TraceHandle,'Ydata');
   set(PickWin.TraceHandle,'Xdata',Xdata,'Ydata',Ydata);
   
   
   % Set the center of the moved window
   NewDist = Seis(index).Dist;
   if strcmp(PlotState.DistanceUnits, 'Degrees')
      PickWin.NewD = Seis(index).Gcarc;
   else
      PickWin.NewD = NewDist;
   end
   if PhaseList.NumPhases > 0 & strcmp(mode,'auto')
      PickWin.NewT = GetClosestPhaseInWindow(PickWin.NewD);
   else
      PickWin.NewT = PickWin.XCenter;
   end
   prsPickWin('MoveTo')
   
   
   
   
   
   PlotTitle = [Seis(index).Name '  ' Seis(index).Component];
   title(PlotTitle)
   PickWin.Npicks = Seis(index).Npicks;
   for j=1:PickWin.Npicks
      PickWin.Pick(j).Header = Seis(index).Pick(j).Header;
      PickWin.Pick(j).Phase = Seis(index).Pick(j).Phase;
      Xdata = get(Seis(index).Pick(j).LineHandle,'Xdata');
      PickWin.Pick(j).Text1 = text(Xdata(1),0, PickWin.Pick(j).Phase,...
                              'erasemode','xor','clipping','on');
      PickWin.Pick(j).Text2 = text(Xdata(1),2,PickWin.Pick(j).Header,...
                              'erasemode','xor','clipping','on');                                                           
      PickWin.Pick(j).LineHandle = line(Xdata, [-1 1],'color','r',...
                                   'erasemode','xor');
   end
end 

w2 = PickWin.Width / 2;
h2 = PickWin.Height / 2;
cx = PickWin.XCenter;
cy = PickWin.YCenter;
  
xlim = [cx-w2, cx+w2];
ylim = [cy-h2, cy+h2];
range = ylim(2) - ylim(1);
PickMarkerSize = range / 5;
lower = ylim(1) + 2 * PickMarkerSize;
upper = ylim(1) + 3 * PickMarkerSize;
PickLim = [lower upper];
for j=1:PickWin.Npicks
   set(PickWin.Pick(j).LineHandle,'Ydata',PickLim)
   pos = get(PickWin.Pick(j).Text1,'Position');
   pos(2) = lower;
   set(PickWin.Pick(j).Text1,'Position', pos)
   pos(2) = upper;
   set(PickWin.Pick(j).Text2,'Position', pos)
end   
set(PickWin.AxisHandle,'xlim',xlim,'ylim',ylim)
axes(oldAxis)
% -------------------------------------------------------------------------






function [Time, minDist] = GetClosestPhaseInWindow(Dist);

global PhaseList
global Seis
global PickWin


%First find a phase line which is closest to current point and within window
CurrentT = PickWin.XCenter;
CurrentD = PickWin.YCenter;
for j=1:PhaseList.NumPhases
   Xdata = get(PhaseList.hPhase(j),'Xdata');
   Ydata = get(PhaseList.hPhase(j),'Ydata');
   dx = Xdata - CurrentT;
   dy = Ydata - CurrentD;
   D = dx.*dx + dy.*dy;
   dmin(j) = min(D);
end
[minDist,I] = min(dmin);
Xdata = get(PhaseList.hPhase(I),'Xdata');
Ydata = get(PhaseList.hPhase(I),'Ydata');
dx = Xdata - CurrentT;
dy = Ydata - CurrentD;
D = dx.*dx + dy.*dy;
[Y, J] = min(D);
if sqrt(Y) > PickWin.Width   % not inside pick window
   Time = CurrentT;
   return
end


% Got to here so we know to use phaseline I
delta = abs(Ydata - Dist);
[Y,K] = min(delta);
Time = Xdata(K);   

% -------------------------------------------------------------------------







